
import java.util.Properties;
import java.net.URL;
import javax.naming.directory.DirContext;
import javax.naming.directory.InitialDirContext;

/**
 * A simple client.
 *
 * <p>Demonstrates how to connect to and retrieve from a 
 * <code>Library</code> instance via JNDI.
 *
 */
public
class Client {

  public
  static
  void
  main(String [] rgstring) {
    if (rgstring.length < 1) {
      System.out.println("Usage: java Client <URL> [name]...");
      System.exit(-1);
    }
    try {
      Properties properties = new Properties();
      // Load the properties from the specified URL.
      properties.load(new URL(rgstring[0]).openStream());
      // Use the properties to establish an initial directory context.
      DirContext dircontext = new InitialDirContext(properties);
      // Get the name of the library.
      String stringName = properties.getProperty("library.name");
      // Lookup a library using the specified name.
      Library library = (Library)dircontext.lookup(stringName);
      // Close the context.
      dircontext.close();
      // For each command-line argument, retrieve the specified object
      // from the library.
      for (int i = 1; i < rgstring.length; i++) {
        Object object = library.retrieve(rgstring[i]);
        // If the object is restorable, restore it.
        if (object instanceof Restorable) {
          Restorable restorable = (Restorable)object;
          restorable.restore();
        }
      }
    }
    catch (Exception exception) {
      exception.printStackTrace();
      System.exit(-1);
    }
  }
}
