
import java.util.Hashtable;
import java.util.Properties;

import java.io.FileInputStream;

import javax.naming.directory.DirContext;
import javax.naming.directory.InitialDirContext;

/**
 * Deploys a <code>JNDILibrary</code> instance.
 *
 * <p>This class should be run as an application.  It deploys a
 * <code>JNDILibrary</code> instance.  It assumes the existence of a
 * properly configured JNDI service (typically, but not necessarily,
 * running LDAP).
 *
 * <p>The application requires a single command-line argument:
 * the name of a file containing the deployment properties.  The
 * properties file may contain any valid JNDI property, as well as the
 * property "library.name", which must contain the name of the
 * library.
 *
 */
public
class JNDIDeploy {

  public
  static
  void
  main(String [] rgstring) {
    if (rgstring.length != 1) {
      System.out.println("Usage: java JNDIDeploy <properties file>");
      System.exit(-1);
    }
    try {
      Properties properties = new Properties();
      // Load the properties from the specified file.
      properties.load(new FileInputStream(rgstring[0]));
      // Use the properties to establish an initial directory context.
	    DirContext dircontext = new InitialDirContext(properties);
      // Create the JNDI library instance and initialize it with the
      // same set of properties (it will publish objects in the same
      // context as itself).
	    JNDILibrary jndilibrary = new JNDILibrary(properties);
      // Get the name of the library.
      String stringName = properties.getProperty("library.name");
      // Bind the library to the specified name.
	    dircontext.rebind(stringName, jndilibrary, null);
      // Close the context.
	    dircontext.close();
    }
    catch (Exception exception) {
      exception.printStackTrace();
      System.exit(-1);
    }
  }
}
