
import java.util.Hashtable;
import java.util.Properties;
import java.io.ByteArrayInputStream;
import javax.naming.spi.ObjectFactory;
import javax.naming.Name;
import javax.naming.Context;
import javax.naming.Reference;
import javax.naming.RefAddr;
import javax.naming.BinaryRefAddr;

/**
 * The <code>JNDILibraryFactory</code> class.
 *
 */
public
class JNDILibraryFactory
implements ObjectFactory {

  /**
   * Creates an object instance given a reference.
   *
   * @param object a reference
   * @param name a name
   * @param context the context
   * @param hashtable the environment
   *
   * @returns an object, or null
   *
   */
  public
  Object
  getObjectInstance(Object object, Name name, Context context, Hashtable hashtable)
  throws Exception {
    // Checks whether or not the object is an instance of a reference.
    if (object instanceof Reference) {
      Reference reference = (Reference)object;
      // Checks whether or not its a valid reference for this factory.
      if (reference.getClassName().equals(JNDILibrary.class.getName())) {
        // Gets the stored payload.
        RefAddr refaddr = reference.get("properties");
        if (refaddr != null) {
          if (refaddr instanceof BinaryRefAddr) {
            BinaryRefAddr binaryrefaddr = (BinaryRefAddr)refaddr;
            // Recreates the stored properties.
            byte [] rgb = (byte [])binaryrefaddr.getContent();
            ByteArrayInputStream bytearrayinputstream = new ByteArrayInputStream(rgb);
            Properties properties = new Properties();
            properties.load(bytearrayinputstream);
            // Creates a new JNDI library with the stored properties.
            return new JNDILibrary(properties);
          }
        }
      }
    }
    return null;
  }
}
